'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-b5d2dca0.js');

const ALLOWED_ANIMATIONS = ['progress', 'progress-dark', 'pulse', 'false'];

const skeletonCss = ".skeleton{-webkit-box-sizing:border-box;box-sizing:border-box;outline:none;overflow:hidden;position:relative;background:var(--skeleton-background, #eff1f6) no-repeat;border-radius:var(--skeleton-border-radius, 4px);width:var(--skeleton-width, 100%);height:var(--skeleton-height, 20px);display:inline-block;margin-bottom:var(--skeleton-margin-bottom, 10px);will-change:transform}.skeleton:after,.skeleton:before{-webkit-box-sizing:border-box;box-sizing:border-box}.skeleton.circle{width:var(--skeleton-width, 40px);height:var(--skeleton-height, 40px);margin-bottom:var(--skeleton-margin-bottom, 5px);border-radius:var(--skeleton-border-radius, 50%)}.skeleton.rect{border-radius:var(--skeleton-border-radius, 0px)}.skeleton.progress,.skeleton.progress-dark{-webkit-animation:progress 2s cubic-bezier(0.4, 0, 0.2, 1) infinite;animation:progress 2s cubic-bezier(0.4, 0, 0.2, 1) infinite;background-size:200px 100%}.skeleton.progress{background-image:-webkit-gradient(linear, left top, right top, from(rgba(255, 255, 255, 0)), color-stop(rgba(255, 255, 255, 0.6)), to(rgba(255, 255, 255, 0)));background-image:linear-gradient(90deg, rgba(255, 255, 255, 0), rgba(255, 255, 255, 0.6), rgba(255, 255, 255, 0))}.skeleton.progress-dark{background-image:-webkit-gradient(linear, left top, right top, from(transparent), color-stop(rgba(0, 0, 0, 0.2)), to(transparent));background-image:linear-gradient(90deg, transparent, rgba(0, 0, 0, 0.2), transparent)}.skeleton.pulse{-webkit-animation:pulse 1.5s cubic-bezier(0.4, 0, 0.2, 1) infinite;animation:pulse 1.5s cubic-bezier(0.4, 0, 0.2, 1) infinite;-webkit-animation-delay:0.5s;animation-delay:0.5s}@media (prefers-reduced-motion: reduce){.skeleton.pulse,.skeleton.progress-dark,.skeleton.progress{-webkit-animation:none;animation:none}.skeleton.progress,.skeleton.progress-dark{background-image:none}}@-webkit-keyframes progress{0%{background-position:-200px 0}100%{background-position:calc(200px + 100%) 0}}@keyframes progress{0%{background-position:-200px 0}100%{background-position:calc(200px + 100%) 0}}@-webkit-keyframes pulse{0%{opacity:1}50%{opacity:0.4}100%{opacity:1}}@keyframes pulse{0%{opacity:1}50%{opacity:0.4}100%{opacity:1}}";

let Skeleton = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Number of rows of current skeleton type
     *
     * @memberof Skeleton
     */
    this.count = 1;
    /**
     * Variant of the skeleton - circle or row
     *
     * @type {('circle' | '')}
     * @memberof Skeleton
     */
    this.variant = 'text';
    /**
     * Width of the skeleton ex. 100px, 100%, auto etc.
     *
     *
     * @type {string}
     * @memberof Skeleton
     */
    this.width = null;
    /**
     * Height of the skeleton ex. 100px, 100%, auto etc.
     *
     * @type {string}
     * @memberof Skeleton
     */
    this.height = null;
    /**
     * MarginBottom of the skeleton ex. 10px, 0 etc.
     *
     * @type {string}
     * @memberof Skeleton
     */
    this.marginBottom = null;
    /**
     * Animation type
     *
     * @type {('progress' | 'progress-dark' | 'pulse' | 'false')}
     * @memberof Skeleton
     */
    this.animation = 'progress';
    /**
     * Custom css styles (background/margins/width/height etc.)
     *
     * @type {({[k: string]: string} | string)}
     * @memberof Skeleton
     */
    this.customStyles = {};
    /**
     * Whether to show warnings for the wrong animation type/custom styles
     *
     * @memberof Skeleton
     */
    this.showWarnings = true;
    this.items = [];
  }
  componentWillLoad() {
    this.init();
  }
  componentWillUpdate() {
    this.init();
  }
  init() {
    this.items.length = this.count;
    this.items.fill(1);
    if (!ALLOWED_ANIMATIONS.includes(this.animation)) {
      if (this.showWarnings) {
        console.warn(`\`Skeleton\` need to receive 'animation' as: ${ALLOWED_ANIMATIONS.join(', ')}. Forcing default to "progress".`);
      }
      this.animation = 'progress';
    }
    if (this.customStyles && typeof this.customStyles === 'string') {
      try {
        this.customStyles = JSON.parse(this.customStyles);
      }
      catch (error) {
        if (this.showWarnings) {
          console.warn(`can't parse styles`, this.customStyles);
        }
      }
    }
  }
  get style() {
    let dimenssionsStyles = {
      width: null,
      height: null,
      marginBottom: null
    };
    if (this.width) {
      dimenssionsStyles.width = this.width;
    }
    if (this.height) {
      dimenssionsStyles.height = this.height;
    }
    if (this.marginBottom) {
      dimenssionsStyles.marginBottom = this.marginBottom;
    }
    const styles = typeof this.customStyles === 'object' ? this.customStyles : {};
    return Object.assign(Object.assign({}, dimenssionsStyles), styles);
  }
  render() {
    return this.items.map((_, index$1) => {
      return (index.h("span", { key: index$1, class: {
          circle: this.variant === 'circle',
          rect: this.variant === 'rect',
          progress: this.animation === 'progress',
          'progress-dark': this.animation === 'progress-dark',
          pulse: this.animation === 'pulse',
          skeleton: true
        }, "aria-busy": "true", "aria-valuemin": "0", "aria-valuemax": "100", "aria-valuetext": "Loading...", role: "progressbar", tabindex: "0", style: this.style }));
    });
  }
};
Skeleton.style = skeletonCss;

exports.nb_skeleton = Skeleton;
