export declare class Skeleton {
  /**
   * Number of rows of current skeleton type
   *
   * @memberof Skeleton
   */
  count: number;
  /**
   * Variant of the skeleton - circle or row
   *
   * @type {('circle' | '')}
   * @memberof Skeleton
   */
  variant: 'circle' | 'rect' | 'text';
  /**
   * Width of the skeleton ex. 100px, 100%, auto etc.
   *
   *
   * @type {string}
   * @memberof Skeleton
   */
  width: string;
  /**
   * Height of the skeleton ex. 100px, 100%, auto etc.
   *
   * @type {string}
   * @memberof Skeleton
   */
  height: string;
  /**
   * MarginBottom of the skeleton ex. 10px, 0 etc.
   *
   * @type {string}
   * @memberof Skeleton
   */
  marginBottom: string;
  /**
   * Animation type
   *
   * @type {('progress' | 'progress-dark' | 'pulse' | 'false')}
   * @memberof Skeleton
   */
  animation: 'progress' | 'progress-dark' | 'pulse' | 'false';
  /**
   * Custom css styles (background/margins/width/height etc.)
   *
   * @type {({[k: string]: string} | string)}
   * @memberof Skeleton
   */
  customStyles: {
    [key: string]: string;
  } | string;
  /**
   * Whether to show warnings for the wrong animation type/custom styles
   *
   * @memberof Skeleton
   */
  showWarnings: boolean;
  items: number[];
  componentWillLoad(): void;
  componentWillUpdate(): void;
  init(): void;
  get style(): {
    width?: string;
    height?: string;
    marginBottom?: string;
  };
  render(): any[];
}
